# Magic value specification utilities

[![Coverage Status](https://coveralls.io/repos/github/MrThearMan/magic-specs/badge.svg?branch=main)](https://coveralls.io/github/MrThearMan/magic-specs?branch=main)
[![GitHub Workflow Status](https://img.shields.io/github/workflow/status/MrThearMan/magic-specs/Tests)](https://github.com/MrThearMan/magic-specs/actions/workflows/main.yml)
[![PyPI](https://img.shields.io/pypi/v/magic-specs)](https://pypi.org/project/magic-specs)
[![GitHub](https://img.shields.io/github/license/MrThearMan/magic-specs)](https://github.com/MrThearMan/magic-specs/blob/main/LICENSE)
[![GitHub last commit](https://img.shields.io/github/last-commit/MrThearMan/magic-specs)](https://github.com/MrThearMan/magic-specs/commits/main)
[![GitHub issues](https://img.shields.io/github/issues-raw/MrThearMan/magic-specs)](https://github.com/MrThearMan/magic-specs/issues)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/magic-specs)](https://pypi.org/project/magic-specs)

```shell
pip install magic_specs
```
---

**Documentation**: [https://mrthearman.github.io/magic-specs/](https://mrthearman.github.io/magic-specs/)

**Source Code**: [https://github.com/MrThearMan/magic-specs](https://github.com/MrThearMan/magic-specs)

---

This library contains utilities for making definitions for magic values.

